@@ -95,8 +95,7 @@ class PriceListLine(ModelSQL, ModelView, MatchMixin):
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
 
         super(PriceListLine, cls).__register__(module_name)
 
@@ -144,7 +143,8 @@ class PriceListLine(ModelSQL, ModelView, MatchMixin):
     def match(self, pattern):
         if 'quantity' in pattern:
             pattern = pattern.copy()
-            if self.quantity > pattern.pop('quantity'):
+            quantity = pattern.pop('quantity')
+            if self.quantity is not None and self.quantity > quantity:
                 return False
         return super(PriceListLine, self).match(pattern)
 
